==> jasperreports-server-cp-4.0.0-src.zip: jasperreports-server-cp-4.0.0-src/jasperserver/jasperserver-war/src/main/webapp/scripts/resource.query.locate.js <==

/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

var resourceQueryLocate = {
    messages:[],
    initialize: function() {
        var resourceOptions = {
            resourceInput : 'resourceUri',
            browseButton : 'browser_button',
            newResourceLink : 'newQueryLink',
            treeId : 'queryTreeRepoLocation',
            providerId : 'queryTreeDataProvider',
            dialogTitle : resourceQueryLocate.messages["resource.QueryLocate.Title"]
        };
        resourceLocator.initialize(resourceOptions);

        var newQueryLink = $('newQueryLink');
        newQueryLink && newQueryLink.observe('click', function() {
            if ($('LOCAL').checked) {
                $('next').click();
            }
        });
    },

    jumpTo: function (pageTo) {
        $('jumpToPage').setValue(pageTo);
        $('jumpButton').click();
        return false;
    }

};

document.observe('dom:loaded', function() {
    resourceQueryLocate.initialize();
});

==> jasperreports-server-cp-5.1.0-src.zip: jasperreports-server-cp-5.1.0-src/jasperserver/jasperserver-war/src/main/webapp/scripts/resource.query.locate.js <==

/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

var resourceQueryLocate = {
    messages:[],
    initialize: function() {
        resourceLocator.initialize({
            resourceInput : 'resourceUri',
            browseButton : 'browser_button',
            newResourceLink : 'newQueryLink',
            treeId : 'queryTreeRepoLocation',
            providerId : 'queryTreeDataProvider',
            dialogTitle : resourceQueryLocate.messages["resource.QueryLocate.Title"],
            selectLeavesOnly: true
        });

        var newQueryLink = $('newQueryLink');
        newQueryLink && newQueryLink.observe('click', function() {
            if ($('LOCAL').checked) {
                $('next').click();
            }
        });
    },

    jumpTo: function (pageTo) {
        $('jumpToPage').setValue(pageTo);
        $('jumpButton').click();
        return false;
    }

};

document.observe('dom:loaded', function() {
    resourceQueryLocate.initialize();
});
